==> haskell-kan-extensions-5.2-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.2
id: kan-extensions-5.2-JBJYWsYZN7dKqdlHJay6De
key: kan-extensions-5.2-JBJYWsYZN7dKqdlHJay6De
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.
category: Data Structures, Monads, Comonads, Functors
abi: a62504e63b58e1f8a762e8314052e310
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda
import-dirs: /usr/lib/ghc-8.6.5/site-local/kan-extensions-5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/kan-extensions-5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/kan-extensions-5.2
hs-libraries: HSkan-extensions-5.2-JBJYWsYZN7dKqdlHJay6De
includes:
    kan-extensions-common.h
depends:
    adjunctions-4.4-10EXU54JTRq8kFIg0ts7A5 array-0.5.3.0 base-4.12.0.0
    comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    distributive-0.6-L2Z1Ut3SFoa7TwkqYDUZRe
    free-5.1-JdtSGeCqDjHq1uSYuzFwy
    invariant-0.5.1-9lxh5BBcWy8KhJEt8kYGu7 mtl-2.2.2
    profunctors-5.3-1xy35EiLpoK41syHomeyFK
    semigroupoids-5.3.2-EaeMvC8hGUc2P26amNaHYi
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.2
id: kan-extensions-5.2-Cneipw3cCGwJdJyOmlMnAf
key: kan-extensions-5.2-Cneipw3cCGwJdJyOmlMnAf
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.
category: Data Structures, Monads, Comonads, Functors
abi: b9a5b3acf5c9bca7d15841adb8f40c4f
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda
import-dirs: /usr/lib/ghc-8.6.5/site-local/kan-extensions-5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/kan-extensions-5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/kan-extensions-5.2
hs-libraries: HSkan-extensions-5.2-Cneipw3cCGwJdJyOmlMnAf
includes:
    kan-extensions-common.h
depends:
    adjunctions-4.4-BYsjW7A3SlqIXAwj8I0V4g array-0.5.3.0 base-4.12.0.0
    comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    distributive-0.6-L2Z1Ut3SFoa7TwkqYDUZRe
    free-5.1-JdtSGeCqDjHq1uSYuzFwy
    invariant-0.5.2-L1ZXRzD1L3ZJHU9yeLRwAp mtl-2.2.2
    profunctors-5.3-1xy35EiLpoK41syHomeyFK
    semigroupoids-5.3.2-EaeMvC8hGUc2P26amNaHYi
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
